##  Meta Model Additions
See the additions to the meta model provided by the application total cost of ownership (TCO) extension.
Item | Applied Changes
---|---
Fact Sheet: Application |
  * New subsection Application Cost:
    * Total Cost of Ownership (calculated)
    * Maintenance Costs
    * Licensing Costs
    * Support Costs
  * New fields on relations:
    * Total Cost of Ownership (calculated) on relation to business capabilities
    * Total Cost of Ownership (calculated) on the relation to organizations


Calculations |
  * Application Total Cost of Ownership
  * Total Cost of Ownership allocated per Business Capability
  * Total Cost of Ownership allocated per Organization


Reports |
  * Application Landscape - TCO allocation per Business Capability
  * Application Landscape - TCO and TIME classification


Dashboard |
  * New KPIs available for the architecture executive dashboard for application total cost of ownership
    * Total cost of ownership of applications
    * Application lifecycle TCO
    * Share of maintenance cost
    * Share of support cost
    * Share of licensing cost
    * Maintenance cost of applications
    * Support cost of applications
    * Licensing cost of applications

The KPIs are not added by default. To learn how to configure the detailed views for the architecture executive dashboard, see [Creating a View](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD#loio97d3b35fe55840129601970f533e50bd__section_tyf_hmm_5fc "https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD#loio97d3b35fe55840129601970f533e50bd__section_tyf_hmm_5fc")and [Selecting Displayed KPIs](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD#loio439deba0a1984e0a91c0cc5e86509156__section_hxb_krm_5fc).


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
